Сгенерируй UI-тест на Python + Selene для: {description}
Контекст: {context}
Требования:
1. Используй Page Object
2. Добавь 2 проверки через `should`
3. Верни ответ в формате, который можно запустить через python, то есть весь текст в комментарии помести, а код нет.
4. Удали из ответа ```